import * as React from "react";
declare class BaseHeightCache {
    heights: Record<string, number>;
    DEFAULT_HEIGHT: number;
    constructor(props?: any);
    get(r: string): number;
    set(r: string, t: number): void;
    getValidity(r: string): boolean;
}
export class HeightCache extends BaseHeightCache {
    validity: Record<string, boolean>;
    constructor(props?: any);
    getValidity(r: string): boolean;
    set(t: string, n: number): void;
    invalidate(r?: string): void;
}
export interface LayoutBaseProps {
    keys: string[];
    heightCache: HeightCache;
}
declare class LayoutBase {
    keys: any;
    heightCache: HeightCache;
    tops: Record<string, number>;
    totalHeight: number;
    constructor(props?: LayoutBaseProps);
    layout(): void;
    getHeight(r: string): number;
    getHeightValidity(r: string): boolean;
    getTop(r: string): number;
    getBottom(r: string): number;
    getTops(): Record<string, number>;
    getTotalHeight(): number;
    getOffsetForKey(r?: string): number;
    getBounds(r: number, a: number): {
        start: number;
        end: number;
    };
    setHeight(r: string, a: number, n?: any): void;
    setKeys(r: string[], n?: any): void;
}
interface LayoutProps {
    keys: string[];
    heightCache: HeightCache;
}
export class Layout extends LayoutBase {
    containerHeight: number;
    stickToBottom?: boolean;
    bottomMargin?: number;
    ANCHOR_OFFSET?: number;
    STICKY_EPSILON?: number;
    STICKY_EPSILON_SETHEIGHT?: number;
    anchorOffset?: number;
    anchor?: any;
    constructor(props?: LayoutProps);
    getOffsetForKey(t: string): number;
    setHeight(a: string, r: number, n?: any): number;
    setKeys(a: string[], r?: any): number;
    setContainerHeight(t: number, a?: any): any;
    setBottomMargin(t: number): void;
    setStickToBottom(t: boolean): void;
    setAnchor(t?: any, a?: any): void;
    findAnchor(t?: any, a?: any, r?: any): any;
    bracketScrollTop(t?: any): number;
    shouldStickToBottom(t: number, n?: number): boolean;
}
export interface ListItemProps {
    ariaLabel?: string;
    ariaExpanded?: boolean;
    id: string;
    children?: any;
    onFocusEnter?: any;
    onFocusWithin?: any;
    onFocusLeave?: any;
    onHeightChange?: any;
    onMouseEnter?: any;
    onMouseOver?: any;
    onMouseLeave?: any;
    onMouseDown?: any;
    onMouseUp?: any;
    className?: string;
    style: React.CSSProperties;
    role?: string;
    height?: number;
    validity: boolean;
    hasFocus?: boolean;
    hasFocusWithin?: boolean;
    isMouseDownOnItem?: boolean;
    shouldHorizontallyScroll?: boolean;
}
export class ListItem extends React.Component<ListItemProps> {
    static displayName: string;
    static defaultProps: {
        ariaLabel: any;
        children: any;
        onFocusEnter: (...args: any[]) => void;
        onFocusWithin: (...args: any[]) => void;
        onFocusLeave: (...args: any[]) => void;
        onHeightChange: (...args: any[]) => void;
        onMouseEnter: (...args: any[]) => void;
        onMouseOver: (...args: any[]) => void;
        onMouseLeave: (...args: any[]) => void;
        onMouseDown: (...args: any[]) => void;
        onMouseUp: (...args: any[]) => void;
        className: string;
        style: {};
        role: string;
        height: any;
        validity: boolean;
        hasFocus: boolean;
        hasFocusWithin: boolean;
        isMouseDownOnItem: boolean;
        shouldHorizontallyScroll: boolean;
    };
    constructor(props: ListItemProps);
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: ListItemProps): boolean;
    componentDidUpdate(): void;
    componentWillUnmount(): void;
    onFocusEnter(r: any): void;
    onFocusWithin(r: any): void;
    onFocusLeave: () => void;
    onMouseEnter(r: any): void;
    onMouseOver(r: any): void;
    onMouseLeave(r: any): void;
    onMouseDown(r: any): void;
    onMouseUp(r: any): void;
    setRef(r: any): void;
    updateHeight(): void;
    maybeFocusNode(): void;
    determineTabIndex(): 0 | -1;
    render(): JSX.Element;
}
export interface ScrollbarProps {
    children?: any;
    width: number;
    height: number;
    contentHeight: number;
    color?: string;
    className?: string;
    monkey?: boolean;
    fade?: boolean;
    anchor: string;
    role: string;
    ariaLabel?: string;
    onScroll: (event: any, r?: any) => void;
    onContentScroll?: (event: any) => void;
    initialScrollTop?: number;
    onTrackClick: any;
    onKeyDown: any;
    onMouseDown?: any;
    ref?: any;
    isEmpty?: boolean;
}
export interface ScrollbarState {
    top: number;
    height: number;
    hidden: boolean;
}
export class Scrollbar extends React.PureComponent<ScrollbarProps, ScrollbarState> {
    static displayName: string;
    static defaultProps: {
        children: any;
        style: any;
        contentHeight: any;
        color: any;
        className: any;
        monkey: boolean;
        fade: boolean;
        anchor: string;
        role: string;
        ariaLabel: any;
        onScroll: any;
        onContentScroll: (...args: any[]) => void;
        onTrackClick: any;
        initialScrollTop: number;
    };
    dragging: boolean;
    track: any;
    constructor(props: ScrollbarProps);
    componentDidMount(): void;
    componentDidUpdate(): void;
    componentWillUnmount(): void;
    static track: {
        to: (r: any) => any;
        page: (r: any) => any;
    };
    onScroll(r: any): void;
    onDragStart: (e: any) => void;
    onDragEnd: () => void;
    onDrag: (e: any) => void;
    onTrackDown: (a: any) => void;
    onTrackUp: () => void;
    setRef(scroller: any): void;
    setTrackRef(track: any): void;
    getScrollHeight: () => any;
    getBarHeight(n?: any): number;
    getTrackHeight: () => any;
    scrollTop(r: any): any;
    scrollWithAnimation: (r: any) => void;
    update: () => void;
    render(): JSX.Element;
}
export interface VirtualizedListProps {
    width: number;
    height: number;
    className?: string;
    keys: any;
    layout: Layout;
    rowRenderer: (key: any) => JSX.Element;
    getAriaLabelForRow: (r: any) => string;
    role: string;
    itemRole: string;
    ariaLabel?: string;
    persistentKeys?: string[];
    fadeScrollbar: boolean;
    onScroll: (event: any, r?: any) => void;
    onScrollEnd: any;
    onKeyDown: any;
    onContentScroll: (event: any) => void;
    onSelectionChange: any;
    shouldHorizontallyScroll: boolean;
    useWindowScroller?: boolean;
    isScrolling?: boolean;
    scrollTop: number;
}
export interface VirtualizedListState {
    start: any;
    end: any;
    tops: any;
    scrolling: boolean;
}
export class List<T, K> extends React.PureComponent<any, any> {
    static defaultProps: {
        className: string;
        layout: any;
        role: string;
        itemRole: string;
        ariaLabel: any;
        persistentKeys: any[];
        fadeScrollbar: boolean;
        onScroll: (...args: any[]) => void;
        onScrollEnd: (...args: any[]) => void;
        onContentScroll: (...args: any[]) => void;
        onSelectionChange: (...args: any[]) => void;
        getAriaLabelForRow: any;
        shouldHorizontallyScroll: boolean;
    };
    protected layout: Layout;
    protected node: any;
    scrollStartTimeout: any;
    scrollTop: number | boolean;
    constructor(e: VirtualizedListProps);
    componentDidMount(): void;
    UNSAFE_componentWillReceiveProps(r: VirtualizedListProps): void;
    componentWillUnmount(): void;
    /**
     * Sets an :isScrolling flag for a small window of time.
     * This flag is used to disable pointer events on the scrollable portion of the Grid.
     * This prevents jerky/stuttery mouse-wheel scrolling.
     */
    _debounceScrollEnded(): void;
    _debounceScrollEndedCallback: () => void;
    onScroll(r: any, x?: any): void;
    onContentScroll(r: any): void;
    onSelectionChange(): void;
    setRef(r: any): void;
    setContentRef(r: any): void;
    getTop(r: any): number;
    getBottom(r: any): number;
    getScrollTop(): any;
    setHeight(r: string, t: number): void;
    setScrollTop(r: number): void;
    getClassName(): string;
    getContentsClassName(): string;
    getVisibleRange(): {
        start: number;
        end: number;
    };
    getContentHeight(): number;
    getContainerHeight(): any;
    getBounds(r: any, t: any): {
        start: number;
        end: number;
    };
    isScrolling(): any;
    isItemInView(r: string): boolean;
    isScrolledToTop(): boolean;
    isScrolledToBottom(): boolean;
    scrollToKey(r: string, x?: any): void;
    scrollToOffset(r: any, x?: any): void;
    bracketScrollTop(r: number): number;
    relayout(): void;
    renderItem(t: string, r: any): JSX.Element;
    renderItems(): any[];
    _handleWindowScroll: () => void;
    renderContents(): JSX.Element;
    render(): JSX.Element;
}
export interface Props {
    onFocusWithin?: Function;
    onFocusEnter?: Function;
    onFocusLeave?: Function;
    children?: any;
}
export class FocusManager extends React.PureComponent<Props> {
    static displayName: string;
    static defaultProps: {
        children: any;
        onFocusEnter: (...args: any[]) => void;
        onFocusWithin: (...args: any[]) => void;
        onFocusLeave: (...args: any[]) => void;
    };
    constructor(props: Props);
    componentWillMount(): void;
    componentWillUnmount(): void;
    onFocus(t: any): void;
    onBlur(t: any): void;
    checkChildIsValid(r: any): void;
    handleBlur(r: any): void;
    render(): React.DetailedReactHTMLElement<{
        onFocus: (t: any) => void;
        onBlur: (t: any) => void;
    }, HTMLElement>;
}
export interface KeyboardNavigableListProps extends VirtualizedListProps {
    itemToFocus?: string;
    initialActiveItem?: string;
    isFocusableItem: any;
    shouldIgnoreScrollKeys?: () => boolean;
    shouldIgnoreArrowKeys?: () => boolean;
    onFocusEnter: any;
    onFocusLeave: any;
    onPageUp: any;
    onPageDown: any;
    onHome: any;
    onEnd: any;
    keyCommands: any[];
    useAriaApplicationMode: boolean;
    hideHiddenStopTabs: boolean;
}
export type KeyboardNavigableListState = {
    hasKeyboardFocus: boolean;
};
export class KeyboardNavigableList<T, K> extends List<KeyboardNavigableListProps, KeyboardNavigableListState> {
    static defaultProps: {
        className: string;
        layout: any;
        role: string;
        itemRole: string;
        ariaLabel: any;
        persistentKeys: any[];
        fadeScrollbar: boolean;
        onScroll: (...args: any[]) => void;
        onScrollEnd: (...args: any[]) => void;
        onContentScroll: (...args: any[]) => void;
        onSelectionChange: (...args: any[]) => void;
        getAriaLabelForRow: any;
        shouldHorizontallyScroll: boolean;
    } & {
        itemToFocus: any;
        initialActiveItem: any;
        isFocusableItems: (...args: any[]) => void;
        onFocusEnter: (...args: any[]) => void;
        onFocusLeave: (...args: any[]) => void;
        onPageUp: any;
        onPageDown: any;
        onHome: any;
        onEnd: any;
        keyCommands: any;
        useAriaApplicationMode: boolean;
        hideHiddenStopTabs: boolean;
        shouldIgnoreScrollKeys: () => boolean;
        shouldIgnoreArrowKeys: () => boolean;
    };
    constructor(props: KeyboardNavigableListProps);
    componentWillReceiveProps(nextProps: KeyboardNavigableListProps, nextState: KeyboardNavigableListState): void;
    possiblySetInitialFocus(r: KeyboardNavigableListProps): void;
    possiblyUpdateInitialActiveItem(r: KeyboardNavigableListProps): void;
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentDidUpdate(): void;
    onScrollEnd(): void;
    onScrollKeyDown(r: any): void;
    onPageUp(r: any): void;
    onPageDown(r: any): void;
    onKeyDownHome(r: any): void;
    onKeyDownEnd(r: any): void;
    onArrowKeyDown(r: any): void;
    onTabKeyDown(r: any): void;
    onKeyUpHome(): void;
    onKeyUpEnd(): void;
    onItemFocusEnter(r: any): void;
    onItemFocusWithin: (r: any) => void;
    onFocusEnter(r: any): void;
    onFocusLeave(r: any): void;
    onItemMouseOver(r: any): void;
    onItemMouseLeave(): void;
    onItemMouseDown(r: any): void;
    onItemMouseUp(): void;
    onFirstHiddenTabStopKeyDown(r: any): void;
    moveFocusOnScrollEnd(): void;
    focus(): void;
    blur(): void;
    getActiveItem(): any;
    setFirstHiddenTabStopRef(r: any): void;
    setLastHiddenTabStopRef(r: any): void;
    moveFocusIntoVisibleScrollRegion(r: any): void;
    updateTabIndexes(): void;
    setActiveItem(r: any): void;
    haveActiveItem(): boolean;
    focusFirstItem(): void;
    focusLastItem(): void;
    focusNextItem(r: any): void;
    getFocusableItemsInView(): any;
    getFirstFocusableItemInView(): void;
    getLastFocusableItemInView(): void;
    getInitialActiveItem(): any;
    getNextActiveItem(r: any, t: any): void;
    renderItem(t: string, r: any): React.CElement<import("ListItem").ListItemProps, ListItem>;
    renderHiddenTabStop(r: any): JSX.Element;
    onMouseInterceptorMouseMove(r: any): void;
    renderMouseInterceptor(): JSX.Element;
    render(): JSX.Element;
}
export interface DynamicListProps extends KeyboardNavigableListProps {
    layout: Layout;
    loadPre: any;
    loadPost: any;
    loadAround: any;
    itemToScroll?: string;
    animateOnScroll?: boolean;
    useWindowScroller?: boolean;
    itemLoadingRenderer?: React.ReactElement;
}
export interface DynamicListState {
}
export class DynamicList<T, K> extends KeyboardNavigableList<DynamicListProps, DynamicListState> {
    static displayName: string;
    protected pendingScrollTop: number | boolean;
    constructor(e: DynamicListProps);
    componentWillReceiveProps(t: DynamicListProps): void;
    scrollToIfNotVisible(t: any): void;
    componentDidUpdate(): void;
    componentDidMount(): void;
    onScroll(r: any): void;
    getScrollTop(): any;
    setHeight(t: string, a: number): void;
    loadMore(): any;
    renderLoading(t: any): React.ReactElement<{
        key: string;
        className: string;
        style: {
            top: number;
            paddingBottom: number;
            paddingTop: number;
            position: string;
            bottom?: undefined;
        } | {
            bottom: number;
            paddingBottom: number;
            paddingTop: number;
            position: string;
            top?: undefined;
        };
    }, string | ((props: any) => React.ReactElement<any, string | any | (new (props: any) => React.Component<any, any, any>)>) | (new (props: any) => React.Component<any, any, any>)>;
    renderItems(shouldRenderLoading?: boolean): React.ReactElement<{
        key: string;
        className: string;
        style: {
            top: number;
            paddingBottom: number;
            paddingTop: number;
            position: string;
            bottom?: undefined;
        } | {
            bottom: number;
            paddingBottom: number;
            paddingTop: number;
            position: string;
            top?: undefined;
        };
    }, string | ((props: any) => React.ReactElement<any, string | any | (new (props: any) => React.Component<any, any, any>)>) | (new (props: any) => React.Component<any, any, any>)>[];
    render(): JSX.Element;
}
interface _Props1 {
    teamId?: string;
    order: number;
    component?: any;
    children: any;
}
export class FocusableSection extends React.PureComponent<_Props1> {
    static defaultProps: {
        children: any;
    };
    componentDidMount(): void;
    componentWillUnmount(): void;
    render(): any;
}
type CallbackFunction = (e?: KeyboardEvent, combo?: string) => boolean;
/**
 * This is useful if you want to have a single entry to combos instead of letting devs create their own combos.
 */
enum KeyBindings {
    moveUp = "up",
    moveDown = "down",
    moveRight = "right",
    moveLeft = "left",
    pageUp = "pageup",
    pageDown = "pagedown",
    home = "home",
    end = "end",
    ctrlHome = "ctrl+home",
    ctrlEnd = "ctrl+end"
}
export default class Mousetrap {
    /**
     * element to attach key events to
     */
    target: HTMLElement | HTMLDocument;
    /**
     * Method to remove all listerners for a target element
     */
    destroy: Function;
    constructor(targetElement?: HTMLElement, useCapture?: boolean);
    /**
     * binds an event to mousetrap
     *
     * can be a single key, a combination of keys separated with +,
     * an array of keys, or a sequence of keys separated by spaces
     *
     * be sure to list the modifier keys first to make sure that the
     * correct key ends up getting bound (the last key in the pattern)
     */
    bind(keys: KeyBindings | string | string[], callback: CallbackFunction, action: string): void;
    /**
     * unbinds an event to mousetrap
     *
     * the unbinding sets the callback function of the specified key combo
     * to an empty function and deletes the corresponding key in the
     * _directMap dict.
     *
     * TODO: actually remove this from the _callbacks dictionary instead
     * of binding an empty function
     *
     * the keycombo+action has to be exactly the same as
     * it was defined in the bind method
     */
    unbind(keys: KeyBindings | string | string[], action: string): void;
    /**
     * triggers an event that has already been bound
     */
    trigger(keys: string, action: string): void;
    /**
     * resets the library back to its initial state.  this is useful
     * if you want to clear out the current keyboard shortcuts and bind
     * new ones - for example if you switch to another page
     */
    reset(): void;
    /**
     * should we stop this event before firing off callbacks
     */
    stopCallback(e: KeyboardEvent, element: HTMLElement): boolean;
    /**
     * exposes _handleKey publicly so it can be overwritten by extensions
     */
    handleKey(): void;
    /**
     * allow custom key mappings
     */
    addKeycodes: (object: any) => void;
}
export class KeyCommands {
    constructor();
    bindAll(r: any): void;
    reset(): void;
    unbindAll(t: any): void;
    trigger(r: any, t: any): void;
}
export interface MessageDynamicListProps extends DynamicListProps {
}
export interface MessageDynamicListState {
}
export class MessageDynamicList extends DynamicList<DynamicListProps, MessageDynamicListState> {
    static displayName: string;
    startKey: any;
    endKey: any;
    constructor(props: DynamicListProps);
    componentDidUpdate(): void;
    UNSAFE_componentWillReceiveProps(r: DynamicListProps): void;
    getOffset(): number;
    getLoadingOffsetTop(): 0 | 40;
    getLoadingOffsetBottom(): 0 | 40;
    getScrollTop(): any;
    getContentHeight(): number;
    getTop(t: string): number;
    getBottom(t: string): number;
    setScrollTop(a: number): void;
    scrollToOffset(a: number): void;
    bracketScrollTop(t: number): number;
    resetRendered(): void;
    loadMore(start?: number, end?: number, props?: Readonly<any> & Readonly<{
        children?: React.ReactNode;
    }>): any;
    relayout(): void;
    recomputeOffsets(props?: MessageDynamicListProps, xx?: any, y?: any): void;
    computeBounds(argument1?: any, argument2?: any): {
        start: any;
        end: any;
    };
    snapBounds(argument1?: any, argument2?: any): {
        start: any;
        end: any;
    };
    renderLoading(t: any): JSX.Element;
    renderEmptyState: () => JSX.Element;
    renderItem(t: string, r: any): React.CElement<import("ListItem").ListItemProps, ListItem>;
    renderRows: () => any[];
    renderItems(): JSX.Element | JSX.Element[];
    renderContents(): JSX.Element;
}
type ChildrenProps = {
    onChildScroll: ({ scrollTop: number }: {
        scrollTop: any;
    }) => void;
    registerChild: (e: Element) => void;
    height: number;
    isScrolling: boolean;
    scrollLeft: number;
    scrollTop: number;
    width: number;
};
type _Props2 = {
    /**
     * Function responsible for rendering children.
     * This function should implement the following signature:
     * ({ height, isScrolling, scrollLeft, scrollTop, width }) => PropTypes.element
     */
    children: ({ onChildScroll, registerChild, height, isScrolling, scrollLeft, scrollTop, width, }: ChildrenProps) => React.ReactNode;
    /** Callback to be invoked on-resize: ({ height, width }) */
    onResize: ({ height, width }: {
        height: number;
        width: number;
    }) => void;
    /** Callback to be invoked on-scroll: ({ scrollLeft, scrollTop }) */
    onScroll: ({ scrollLeft, scrollTop }: {
        scrollLeft: number;
        scrollTop: number;
    }) => void;
    /** Element to attach scroll event listeners. Defaults to window. */
    scrollElement: typeof window | Element;
    /**
     * Wait this amount of time after the last scroll event before resetting child `pointer-events`.
     */
    scrollingResetTimeInterval: number;
    /** Height used for server-side rendering */
    serverHeight: number;
    /** Width used for server-side rendering */
    serverWidth: number;
};
type State = {
    height: number;
    width: number;
    isScrolling: boolean;
    scrollLeft: number;
    scrollTop: number;
};
type ResizeHandler = (element: Element, onResize: () => void) => void;
type DetectElementResize = {
    addResizeListener: ResizeHandler;
    removeResizeListener: ResizeHandler;
};
export class WindowScroller extends React.PureComponent<_Props2, State> {
    static defaultProps: {
        onResize: () => void;
        onScroll: () => void;
        scrollingResetTimeInterval: number;
        scrollElement: Window & typeof globalThis;
        serverHeight: number;
        serverWidth: number;
    };
    _window: Window & typeof globalThis;
    _isMounted: boolean;
    _positionFromTop: number;
    _positionFromLeft: number;
    _detectElementResize: DetectElementResize;
    _child: Element;
    state: {
        isScrolling: boolean;
        scrollLeft: number;
        scrollTop: number;
        height: number;
        width: number;
    };
    updatePosition(scrollElement?: Element | (Window & typeof globalThis)): void;
    componentDidMount(): void;
    componentDidUpdate(prevProps: _Props2, prevState: State): void;
    componentWillUnmount(): void;
    render(): React.ReactNode;
    _registerChild: (element: any) => void;
    _onChildScroll: ({ scrollTop }: {
        scrollTop: any;
    }) => void;
    _registerResizeListener: (element: any) => void;
    _unregisterResizeListener: (element: any) => void;
    _onResize: () => void;
    __handleWindowScrollEvent: () => void;
    __resetIsScrolling: () => void;
}
type Size = {
    height: number;
    width: number;
};
type _Props3 = {
    /** Function responsible for rendering children.*/
    children: (size: Size) => React.ReactElement;
    /** Optional custom CSS class name to attach to root AutoSizer element.  */
    className?: string;
    /** Default height to use for initial render; useful for SSR */
    defaultHeight?: number;
    /** Default width to use for initial render; useful for SSR */
    defaultWidth?: number;
    /** Disable dynamic :height property */
    disableHeight: boolean;
    /** Disable dynamic :width property */
    disableWidth: boolean;
    /** Nonce of the inlined stylesheet for Content Security Policy */
    nonce?: string;
    /** Callback to be invoked on-resize */
    onResize: (size: Size) => void;
    /** Optional inline style */
    style?: React.CSSProperties;
};
type _State1 = {
    height: number;
    width: number;
};
type _ResizeHandler1 = (element: HTMLElement, onResize: () => void) => void;
type _DetectElementResize1 = {
    addResizeListener: _ResizeHandler1;
    removeResizeListener: _ResizeHandler1;
};
export class AutoSizer extends React.Component<_Props3, _State1> {
    static defaultProps: {
        onResize: () => void;
        disableHeight: boolean;
        disableWidth: boolean;
        style: {};
    };
    state: {
        height: number;
        width: number;
    };
    _parentNode?: any;
    _autoSizer?: any;
    _window?: any;
    _detectElementResize: _DetectElementResize1;
    componentDidMount(): void;
    componentWillUnmount(): void;
    render(): JSX.Element;
    _onResize: () => void;
    _setRef: (autoSizer?: any) => void;
}

//# sourceMappingURL=types.d.ts.map
